PACSLTK (PACS Lambda ToolKit)
=============================

Developed in PACS Lab to ease the process of deployment and testing of
our benchmarking workload to AWS Lambda. To see how you can use pacsltk,
check out the `github
repository <https://github.com/nimamahmoudi/serverless-performance-modeling>`__.

Installation
------------

.. code:: sh

   pip install pacsltk

Updating README in RST file
---------------------------

.. code:: sh

   pandoc -s README.md -o README.rst
